\name{summary.dtrace}
\alias{summary.dtrace}
\alias{print.summary.dtrace}
\title{Summaries for dtrace Objects}
\description{
  This function gathers and returns useful information from
  density trace objects.  A print method is defined so that the
  values computed by this function are printed nicely.
}
\usage{
\method{summary}{dtrace}(object, \ldots)
\method{print}{summary.dtrace}(x, digits = max(4, getOption("digits") - 4), \dots)
}
\arguments{
  \item{object}{An object of class \code{dtrace}.}
  \item{x}{An object of class \code{summary.dtrace}.}
  \item{digits}{The number of significant digits to be used in
    printing.}
  \item{\dots}{Other arguments to be passed to print.}
}
\value{
  The \code{summary} method for \code{dtrace} objects returns a
  list with components:
  \item{xlim}{The range of x values covered by all the density estimates
    in the first argument.}
  \item{ylim}{The range of y values covered by all the density estimates
    in the first argument.}
  \item{names}{The names associated with each group for which a density
    estimate was obtained.}
  \item{nobs}{The number of observations in each group for which a
    density estimate was obtained.}
  \item{bw}{The bandwidth(s) of the kernel(s) used to compute the
    density estimates (see \code{\link{dtrace}}).}
  \item{sd}{The standard deviation(s) of the kernel(s) used to compute
    the density estimates (see \code{\link{dtrace}}).}
}
\author{Ross Ihaka.}
\seealso{\code{\link{dtrace}}.}
\examples{
## Simple density estimation.
## Here we are using automatic bandwidth selection.
data(faithful)
d <- dtrace(faithful$eruptions, sd = "sj")
plot(d, xlab = paste("Kernel Bandwidth =",
                     signif(summary(d)$bw, 4)),
     main = "Old Faithful Data")
}
\keyword{distribution}
\keyword{smooth}
